TerminuiCommand<S> class abstract

Constructors

TerminuiCommand()

Properties

description String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
parser → ArgParser
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(S subject, ArgResults results) → (String?, String)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optionalIntResult(String key, ArgResults results) int?
run(S subject, List<String> args) → (String?, String)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited